@@ -1,3 +1,4 @@
+/* this header file comes from libowfat, http://www.fefe.de/libowfat/ */
 #ifndef IO_H
 #define IO_H
 
@@ -6,6 +7,10 @@
 #include "uint64.h"
 #include "taia.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* like open(s,O_RDONLY) */
 /* return 1 if ok, 0 on error */
 int io_readfile(int64* d,const char* s);
@@ -71,7 +76,8 @@ int64 io_canwrite();
 int64 io_timeouted();
 
 /* put d on internal data structure, return 1 on success, 0 on error */
-int io_fd(int64 d);
+int io_fd(int64 d);		/* use this for sockets before you called connect() or accept() */
+int io_fd_canwrite(int64 d);	/* use this for connected sockets (assumes socket is writable) */
 
 void io_setcookie(int64 d,void* cookie);
 void* io_getcookie(int64 d);
@@ -103,6 +109,8 @@ int io_passfd(int64 sock,int64 fd);
  * process.  Return sock if ok, -1 on error, setting errno. */
 int64 io_receivefd(int64 sock);
 
+int io_starteventloopthread(unsigned int threads);
+
 typedef int64 (*io_write_callback)(int64 s,const void* buf,uint64 n);
 
 /* used internally, but hey, who knows */
@@ -112,4 +120,8 @@ int64 io_mmapwritefile(int64 out,int64 in,uint64 off,uint64 bytes,io_write_callb
 #include_next <io.h>
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
