@@ -1,3 +1,4 @@
+/* this header file comes from libowfat, http://www.fefe.de/libowfat/ */
 #ifndef _IOB_H
 #define _IOB_H
 
@@ -15,6 +16,10 @@
 #include "io.h"
 #include "array.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct io_batch {
   array b;
   uint64 bytesleft;
@@ -36,4 +41,8 @@ void iob_free(io_batch* b);
 void iob_prefetch(io_batch* b,uint64 bytes);
 uint64 iob_bytesleft(const io_batch* b);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
