@@ -1,6 +1,11 @@
+/* this header file comes from libowfat, http://www.fefe.de/libowfat/ */
 #ifndef IP4_H
 #define IP4_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 unsigned int scan_ip4(const char *src,char *ip);
 unsigned int fmt_ip4(char *dest,const char *ip);
 
@@ -13,4 +18,8 @@ unsigned int fmt_ip4(char *dest,const char *ip);
 
 extern const char ip4loopback[4]; /* = {127,0,0,1};*/
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
