@@ -28,7 +28,7 @@ char* mmap_private(const char* filename,size_t * filesize) {
   char *map;
   if (fd>=0) {
     *filesize=lseek(fd,0,SEEK_END);
-    map=mmap(0,*filesize,PROT_READ|PROT_WRITE,MAP_PRIVATE,fd,0);
+    map=(char*)mmap(0,*filesize,PROT_READ|PROT_WRITE,MAP_PRIVATE,fd,0);
     if (map==(char*)-1)
       map=0;
     close(fd);
