@@ -4,7 +4,8 @@
 void fmt_to_array(size_t (*func)(char*,const char*,size_t),
 		  array* a,const char* src,size_t len) {
   size_t needed=func(0,src,len);
-  if (array_allocate(a,1,array_bytes(a)+needed-1)) {
+  if (array_bytes(a)+needed>needed &&
+      array_allocate(a,1,array_bytes(a)+needed-1)) {
     char* x=((char*)array_start(a))+array_bytes(a)-needed;
     func(x,src,len);
   } else
